Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Well-Architected Tool.

Actions, resources, and condition keys for AWS Well-Architected Tool - Service Authorization Reference

# Actions, resources, and condition keys for AWS Well-Architected Tool

AWS Well-Architected Tool (service prefix: `wellarchitected` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS Well-Architected Tool
- Resource types defined by AWS Well-Architected Tool
- Condition keys for AWS Well-Architected Tool

## Actions defined by AWS Well-Architected Tool

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AssociateLenses | Grants permission to associate a lens to the specified workload | Write | workload* |  |
AssociateProfiles | Grants permission to associate a profile to the specified workload | Write | workload* |  |
ConfigureIntegration [permission only] | Grants permission to configure the integration | Write |  |  |
CreateLensShare | Grants permission to an owner of a lens to share with other AWS accounts and IAM users | Write | lens* |  |
CreateLensVersion | Grants permission to create a new lens version | Write | lens* |  |
CreateMilestone | Grants permission to create a new milestone for the specified workload | Write | workload* |  |
CreateProfile | Grants permission to create a new profile | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateProfileShare | Grants permission to an owner of a profile to share with other AWS accounts and IAM users | Write | profile* |  |
CreateReviewTemplate | Grants permission to create a new review template | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateTemplateShare | Grants permission to an owner of a review template to share with other AWS accounts and IAM users | Write | review-template* |  |
CreateWorkload | Grants permission to create a new workload | Write |  | aws:RequestTag/${TagKey} aws:TagKeys wellarchitected:JiraProjectKey |
CreateWorkloadShare | Grants permission to share a workload with another account | Write | workload* |  |
DeleteLens | Grants permission to delete a lens | Write | lens* |  |
DeleteLensShare | Grants permission to delete an existing lens share | Write | lens* |  |
DeleteProfile | Grants permission to delete a profile | Write | profile* |  |
DeleteProfileShare | Grants permission to delete an existing profile share | Write | profile* |  |
DeleteReviewTemplate | Grants permission to delete an existing review template | Write | review-template* |  |
DeleteTemplateShare | Grants permission to delete an existing review template share | Write | review-template* |  |
DeleteWorkload | Grants permission to delete an existing workload | Write | workload* |  |
DeleteWorkloadShare | Grants permission to delete an existing workload share | Write | workload* |  |
DisassociateLenses | Grants permission to disassociate a lens from the specified workload | Write | workload* |  |
DisassociateProfiles | Grants permission to disassociate a profile from the specified workload | Write | workload* |  |
ExportLens | Grants permission to export an existing lens | Read | lens* |  |
GetAnswer | Grants permission to retrieve the specified answer from the specified lens review | Read | workload* |  |
GetConsolidatedReport | Grants permission to get consolidated report metrics or to generate the consolidated report PDF in this account | Read |  |  |
GetGlobalSettings | Grants permission to get all settings for the account | Read |  |  |
GetLens | Grants permission to get an existing lens | Read | lens* |  |
| aws:ResourceTag/${TagKey} |
GetLensReview | Grants permission to retrieve the specified lens review of the specified workload | Read | workload* |  |
GetLensReviewReport | Grants permission to retrieve the report for the specified lens review | Read | workload* |  |
GetLensVersionDifference | Grants permission to get the difference between the specified lens version and latest available lens version | Read | lens* |  |
GetMilestone | Grants permission to retrieve the specified milestone of the specified workload | Read | workload* |  |
GetProfile | Grants permission to retrieve the specified profile | Read | profile* |  |
| aws:ResourceTag/${TagKey} |
GetProfileTemplate | Grants permission to retrieve the specified profile template | Read |  |  |
GetReviewTemplate | Grants permission to retrieve the specified review template | Read | review-template* |  |
| aws:ResourceTag/${TagKey} |
GetReviewTemplateAnswer | Grants permission to retrieve the specified answer from the specified review template lens review | Read | review-template* |  |
GetReviewTemplateLensReview | Grants permission to retrieve the specified lens review of the specified review template | Read | review-template* |  |
GetWorkload | Grants permission to retrieve the specified workload | Read | workload* |  |
| aws:ResourceTag/${TagKey} |
ImportLens | Grants permission to import a new lens | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
ListAnswers | Grants permission to list the answers from the specified lens review | List | workload* |  |
ListCheckDetails | Grants permission to list the check-details for the workload | List | workload* |  |
ListCheckSummaries | Grants permission to list the check-summaries for the workload | List | workload* |  |
ListLensReviewImprovements | Grants permission to list the improvements of the specified lens review | List | workload* |  |
ListLensReviews | Grants permission to list the lens reviews of the specified workload | List | workload* |  |
ListLensShares | Grants permission to list all shares created for a lens | List | lens* |  |
ListLenses | Grants permission to list the lenses available to this account | List |  |  |
ListMilestones | Grants permission to list the milestones of the specified workload | List | workload* |  |
ListNotifications | Grants permission to list notifications related to the account or specified resource | List |  |  |
ListProfileNotifications | Grants permission to list profile notifications related to specified resource | List |  |  |
ListProfileShares | Grants permission to list all shares created for a profile | List | profile* |  |
ListProfiles | Grants permission to list the profiles available to this account | List |  |  |
ListReviewTemplateAnswers | Grants permission to list the answers from the specified review template lens review | List | review-template* |  |
ListReviewTemplates | Grants permission to list the review templates available to this account | List |  |  |
ListShareInvitations | Grants permission to list the workload share invitations of the specified account or user | List |  |  |
ListTagsForResource | Grants permission to list tags for a Well-Architected resource | Read | lens |  |
profile |  |
review-template |  |
workload |  |
| aws:ResourceTag/${TagKey} |
ListTemplateShares | Grants permission to list all shares created for a review template | List | review-template* |  |
ListWorkloadShares | Grants permission to list the workload shares of the specified workload | List | workload* |  |
ListWorkloads | Grants permission to list the workloads in this account | List |  |  |
TagResource | Grants permission to tag a Well-Architected resource | Tagging | lens |  |
profile |  |
review-template |  |
workload |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | Grants permission to untag a Well-Architected resource | Tagging | lens |  |
profile |  |
review-template |  |
workload |  |
| aws:TagKeys |
UpdateAnswer | Grants permission to update properties of the specified answer | Write | workload* |  |
UpdateGlobalSettings | Grants permission to manage all settings for the account | Write |  | wellarchitected:JiraProjectKey |
UpdateIntegration | Grants permission to update properties of the integration | Write | workload* |  |
UpdateLensReview | Grants permission to update properties of the specified lens review | Write | workload* |  |
UpdateProfile | Grants permission to update properties of the specified profile | Write | profile* |  |
UpdateReviewTemplate | Grants permission to update properties of the specified review template | Write | review-template* |  |
UpdateReviewTemplateAnswer | Grants permission to update properties of the specified review template answer | Write | review-template* |  |
UpdateReviewTemplateLensReview | Grants permission to update properties of the specified review template lens review | Write | review-template* |  |
UpdateShareInvitation | Grants permission to update status of the specified workload share invitation | Write |  |  |
UpdateWorkload | Grants permission to update properties of the specified workload | Write | workload* |  |
| wellarchitected:JiraProjectKey |
UpdateWorkloadShare | Grants permission to update properties of the specified workload share | Write | workload* |  |
UpgradeLensReview | Grants permission to upgrade the specified lens review to use the latest version of the associated lens | Write | workload* |  |
UpgradeProfileVersion | Grants permission to upgrade the specified workload to use the latest version of the associated profile | Write | profile* |  |
workload* |  |
UpgradeReviewTemplateLensReview | Grants permission to upgrade the specified lens review of the specified review template | Write | review-template* |  |

## Resource types defined by AWS Well-Architected Tool

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
workload | `arn:$ { Partition}:wellarchitected:$ { Region}:$ { Account}:workload/$ { ResourceId}` | aws:ResourceTag/${TagKey}
lens | `arn:$ { Partition}:wellarchitected:$ { Region}:$ { Account}:lens/$ { ResourceId}` | aws:ResourceTag/${TagKey}
profile | `arn:$ { Partition}:wellarchitected:$ { Region}:$ { Account}:profile/$ { ResourceId}` | aws:ResourceTag/${TagKey}
review-template | `arn:$ { Partition}:wellarchitected:$ { Region}:$ { Account}:review-template/$ { ResourceId}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS Well-Architected Tool

AWS Well-Architected Tool defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters access by tag key-value pairs attached to the resource | String
aws:TagKeys | Filters access by tag keys in the request | ArrayOfString
wellarchitected:JiraProjectKey | Filters access by project key | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.